% Plots the orbit around the Lorenz chaotic attractor.
% Returns the points in Y.
%
% Adapted from Matlab's LORENZ demo.

global SIGMA RHO BETA
SIGMA = 10.;
RHO = 28.;
BETA = 8./3.;
FunFcn='lorenzeq';

% The initial conditions below will produce good results
%y0 = [20 5 -5];
% Random initial conditions
y0(1)=rand*30+5;
y0(2)=rand*35-30;
y0(3)=rand*40-5;
t0=0;
tfinal=100;
pow = 1/3;
tol = 0.001;

t = t0;
hmax = (tfinal - t)/5;
hmin = (tfinal - t)/200000;
h = (tfinal - t)/100;
y = y0(:);
tau = tol * max(norm(y,'inf'),1);

figure(1); clf;
hold on;

Y=[];

while h >= hmin
  if t + h > tfinal, h = tfinal - t; end
  % Compute the slopes
  s1 = feval(FunFcn, t, y);
  s2 = feval(FunFcn, t+h, y+h*s1);
  s3 = feval(FunFcn, t+h/2, y+h*(s1+s2)/4);
  
  % Estimate the error and the acceptable error
  delta = norm(h*(s1 - 2*s3 + s2)/3,'inf');
  tau = tol*max(norm(y,'inf'),1.0);
  
  % Update the solution only if the error is acceptable
  ts = t;
  ys = y;
  if delta <= tau
    t = t + h;
    old_y = y;
    y = y + h*(s1 + 4*s3 + s2)/6;
    plot3([old_y(1) y(1)],[old_y(2) y(2)],[old_y(3) y(3)],'b-');
  end
  
  % Update the step size
  if delta ~= 0.0
    h = min(hmax, 0.9*h*(tau/delta)^pow);
  end
  
  Y = [Y y];
  
%pause
end;    % Main loop ...
hold off;

set(gca,'XTickLabel',[],'YTickLabel',[],'ZTickLabel',[],'Box','off',...
        'DataAspectRatio',[1 1 1]);
grid on;
xlabel('t1'); ylabel('t2'); zlabel('t3');
view(-70,40);

% EPS file
%print -depsc lorenz
